Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(672)

Unified Diff: runtime/lib/regexp_patch.dart

Issue 23566008: Rename Match.str to input. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | sdk/lib/_collection_dev/iterable.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/lib/regexp_patch.dart
diff --git a/runtime/lib/regexp_patch.dart b/runtime/lib/regexp_patch.dart
index 72b6f4bf827755d7465b50dab117aa45bef4a3cc..2fdee65e3a8c8ae9e323714b951c9c6c6e8bc4e0 100644
--- a/runtime/lib/regexp_patch.dart
+++ b/runtime/lib/regexp_patch.dart
@@ -3,10 +3,10 @@
// BSD-style license that can be found in the LICENSE file.
patch class RegExp {
/* patch */ factory RegExp(String pattern,
{bool multiLine: false,
bool caseSensitive: true}) {
- return new _JSSyntaxRegExp(pattern,
+ return new _JSSyntaxRegExp(source,
multiLine: multiLine,
caseSensitive: caseSensitive);
}
@@ -3,10 +3,10 @@
// BSD-style license that can be found in the LICENSE file.
patch class RegExp {
- /* patch */ factory RegExp(String pattern,
+ /* patch */ factory RegExp(String source,
{bool multiLine: false,
bool caseSensitive: true}) {
« no previous file with comments | « no previous file | sdk/lib/_collection_dev/iterable.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698